@@ -7,14 +7,14 @@ The used terms are defined in the README_conditions.md.
 # pylint:disable=cyclic-import
 from typing import List, Union
 
-from lark import Lark, Tree
+from lark import Lark, Token, Tree
 from lark.exceptions import UnexpectedCharacters, UnexpectedEOF
 
 from ahbicht.condition_node_distinction import ConditionNodeType, derive_condition_node_type
 from ahbicht.content_evaluation.categorized_key_extract import CategorizedKeyExtract
 
 
-def parse_condition_expression_to_tree(condition_expression: str) -> Tree:
+def parse_condition_expression_to_tree(condition_expression: str) -> Tree[Token]:
     """
     Parse a given condition expression with the help of the here defined grammar to a lark tree.
     The grammar starts with condition keys, e.g. [45] and combines them with
@@ -26,7 +26,7 @@ def parse_condition_expression_to_tree(condition_expression: str) -> Tree:
     :return parsed_tree: Tree
     """
 
-    grammar = """
+    grammar = r"""
     ?expression: expression "O"i expression -> or_composition
                 | expression "∨" expression -> or_composition
                 | expression "X"i expression -> xor_composition
@@ -38,15 +38,15 @@ def parse_condition_expression_to_tree(condition_expression: str) -> Tree:
                 | package
                 | condition
     ?brackets: "(" expression ")"
-    package: "[" PACKAGE_KEY "]" // a rule for packages
+    package: "[" PACKAGE_KEY REPEATABILITY? "]" // a rule for packages
     condition: "[" CONDITION_KEY "]" // a rule for condition keys
     CONDITION_KEY: INT // a TERMINAL for all the remaining ints (lower priority)
+    REPEATABILITY: /\d+\.{2}[1-9]\d*/ // a terminal for repetitions n..m with n>=0 and m>n
     PACKAGE_KEY: INT "P" // a TERMINAL for all INTs followed by "P" (high priority)
     %import common.INT
     %import common.WS
     %ignore WS  // WS = whitespace
     """
-    # todo: add wiederholbarkeiten https://github.com/Hochfrequenz/ahbicht/issues/96
     parser = Lark(grammar, start="expression")
     try:
         parsed_tree = parser.parse(condition_expression)
@@ -54,13 +54,12 @@ def parse_condition_expression_to_tree(condition_expression: str) -> Tree:
         raise SyntaxError(
             """Please make sure that:
              * all conditions have the form [INT]
-             * all packages have the form [INTP]
+             * all packages have the form [INTPn..m]
              * no conditions are empty
              * all compositions are combined by operators 'U'/'O'/'X' or without an operator
              * all open brackets are closed again and vice versa
              """
         ) from eof
-    # todo: implement wiederholbarkeiten
     return parsed_tree
 
 
