@@ -5,7 +5,7 @@ Schemata for the JSON serialization of expressions.
 from typing import Optional, Union
 
 from lark import Token, Tree
-from marshmallow import Schema, fields, post_dump, post_load, pre_dump, pre_load
+from marshmallow import Schema, fields, post_load, pre_dump
 
 # in the classes/schemata we don't care about if there aren't enough public versions.
 # We also don't care about unused kwargs, or no self-use.
@@ -108,47 +108,3 @@ class TreeSchema(Schema):
         :return:
         """
         return Tree(**data)
-
-
-def _compress(data: dict) -> dict:
-    """
-    a function that "throws away" unnecessary data.
-    The price we pay is that we loose the ability to easily deserialize the result.
-    But if we're only interested in a simple tree that's fine.
-    """
-    if (
-        "children" in data
-        and "type" in data
-        and (data["type"].endswith("_composition") or data["type"].endswith("_expression"))
-    ):
-        return {data["type"]: [_compress(child) for child in data["children"]]}
-    if "tree" in data and "token" in data and data["token"] is None:
-        return _compress(data["tree"])
-    if "tree" in data and "token" in data and data["tree"] is None:
-        return _compress(data["token"])
-    if "type" in data and "children" in data:  # and data["type"] in {"MODAL_MARK", "condition_key"}:
-        return _compress(data["children"][0]["token"]["value"])
-    if "type" in data and data["type"] in {"MODAL_MARK"}:
-        return data["value"]
-    return data
-
-
-class ConciseTreeSchema(TreeSchema):
-    """
-    A tree schema that leads to significantly more compact output but can only be used for serialization
-    (not deserialization)
-    """
-
-    @post_dump
-    def serialize(self, data, **kwargs) -> dict:
-        """
-        Serialize as compact/concise tree
-        """
-        return _compress(data)
-
-    @pre_load
-    def deserialize(self, data, **kwargs) -> Tree:
-        """
-        This is out of scope
-        """
-        raise NotImplementedError("Deserializing a compact tree is not supported.")
