@@ -1,3 +1,4 @@
+# type:ignore[misc]
 """ Tests for the parsing of the conditions tests (Mussfeldprüfung) """
 
 import pytest  # type:ignore[import]
@@ -146,7 +147,7 @@ class TestConditionParser:
             ),
         ],
     )
-    def test_parse_valid_expression_to_tree(self, expression: str, expected_tree: Tree):
+    def test_parse_valid_expression_to_tree(self, expression: str, expected_tree: Tree[Token]):
         """
         Tests that valid expressions containing operators "O"/"U"/"X", different whitespaces
         and no brackets are parsed as expected.
@@ -448,6 +449,23 @@ class TestConditionParser:
                     ],
                 ),
             ),
+            pytest.param(
+                # nested brackets
+                "[10P1..5]U([1]O[2])",
+                Tree(
+                    "and_composition",
+                    [
+                        Tree(Token("RULE", "package"), [Token("PACKAGE_KEY", "10P"), Token("REPEATABILITY", "1..5")]),
+                        Tree(
+                            "or_composition",
+                            [
+                                Tree(Token("RULE", "condition"), [Token("CONDITION_KEY", "1")]),
+                                Tree(Token("RULE", "condition"), [Token("CONDITION_KEY", "2")]),
+                            ],
+                        ),
+                    ],
+                ),
+            ),
         ],
     )
     def test_parse_valid_expression_with_brackets_to_tree(self, expression: str, expected_tree: Tree):
@@ -483,7 +501,7 @@ class TestConditionParser:
 
         assert """Please make sure that:
              * all conditions have the form [INT]
-             * all packages have the form [INTP]
+             * all packages have the form [INTPn..m]
              * no conditions are empty
              * all compositions are combined by operators 'U'/'O'/'X' or without an operator
              * all open brackets are closed again and vice versa
